@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009, Sebastian Riedel.
+# Copyright (C) 2008-2010, Sebastian Riedel.
 
 package Mojo::Command::FcgiPrefork;
 
@@ -26,12 +26,15 @@ These options are available:
                           killed, defaults to 30.
   --interval <seconds>    Set interval for process maintainance, defaults to
                           15.
-  --keepalive <seconds>   Set keep-alive timeout, defaults to 15.
   --listen <path>         Set listen socket path, defaults to :3000.
+  --lock <path>           Set path to lock file, defaults to a random
+                          temporary file.
   --maxspare <number>     Set maximum amount of idle children, defaults to 10.
   --minspare <number>     Set minimum amount of idle children, defaults to 5.
   --pid <path>            Set path to pid file, defaults to a random
                           temporary file.
+  --reload                Automatically reload application when the source
+                          code changes.
   --requests <number>     Set maximum number of requests per keep-alive
                           connection, defaults to 100.
   --servers <number>      Set maximum number of children, defaults to 100.
@@ -49,20 +52,21 @@ sub run {
     my $daemonize;
     @ARGV = @_ if @_;
     GetOptions(
-        'clients=i'   => sub { $fcgi->max_clients($_[1]) },
-        'daemonize'   => \$daemonize,
-        'group=s'     => sub { $fcgi->group($_[1]) },
-        'idle=i'      => sub { $fcgi->idle_timeout($_[1]) },
-        'interval=i'  => sub { $fcgi->cleanup_interval($_[1]) },
-        'keepalive=i' => sub { $fcgi->keep_alive_timeout($_[1]) },
-        'listen=s'    => sub { $fcgi->listen($_[1]) },
-        'maxspare=i'  => sub { $fcgi->max_spare_servers($_[1]) },
-        'minspare=i'  => sub { $fcgi->min_spare_servers($_[1]) },
-        'pid=s'       => sub { $fcgi->pid_file($_[1]) },
-        'requests=i'  => sub { $fcgi->max_keep_alive_requests($_[1]) },
-        'servers=i'   => sub { $fcgi->max_servers($_[1]) },
-        'start=i'     => sub { $fcgi->start_servers($_[1]) },
-        'user=s'      => sub { $fcgi->user($_[1]) }
+        'clients=i'  => sub { $fcgi->max_clients($_[1]) },
+        daemonize    => \$daemonize,
+        'group=s'    => sub { $fcgi->group($_[1]) },
+        'idle=i'     => sub { $fcgi->idle_timeout($_[1]) },
+        'interval=i' => sub { $fcgi->cleanup_interval($_[1]) },
+        'listen=s'   => sub { $fcgi->listen($_[1]) },
+        'lock=s'     => sub { $fcgi->lock_file($_[1]) },
+        'maxspare=i' => sub { $fcgi->max_spare_servers($_[1]) },
+        'minspare=i' => sub { $fcgi->min_spare_servers($_[1]) },
+        'pid=s'      => sub { $fcgi->pid_file($_[1]) },
+        reload       => sub { $fcgi->reload(1) },
+        'requests=i' => sub { $fcgi->max_keep_alive_requests($_[1]) },
+        'servers=i'  => sub { $fcgi->max_servers($_[1]) },
+        'start=i'    => sub { $fcgi->start_servers($_[1]) },
+        'user=s'     => sub { $fcgi->user($_[1]) }
     );
 
     # Daemonize
